@@ -1,12 +1,14 @@
-import json
-import httpx
 import asyncio
-import websockets
+import json
 import logging
+
+import httpx
+import websockets
+
 logger = logging.getLogger()
 
-from typing import Optional
 from dataclasses import dataclass
+from typing import Optional
 
 from .helpers import req_wrap
 
@@ -34,7 +36,6 @@ class MempoolClient:
         # just check if mempool is available
         self.get_blockheight()
 
-
     def request(self, funcname, *args, **kwargs) -> dict:
         try:
             return req_wrap(funcname, *args, **kwargs)
@@ -45,9 +46,8 @@ class MempoolClient:
             msg = f"{exc.response.status_code} while requesting {exc.request.url!r}. message: {exc.response.text}"
             raise MempoolApiException(f"mempool api status error: {msg}")
 
-
     async def wait_for_websocket_message(self, send, message_key):
-        async for websocket in websockets.connect(self._ws_url): #type: ignore
+        async for websocket in websockets.connect(self._ws_url):  # type: ignore
             try:
                 # await websocket.send(json.dumps({"action": "init"}))
                 # await websocket.send(json.dumps({"action": "want", "data": ["blocks", "mempool-blocks"]}))
@@ -57,24 +57,25 @@ class MempoolClient:
                     message = json.loads(raw)
                     if message_key in message:
                         return message.get(message_key)
-            except websockets.ConnectionClosed: #type: ignore
+            except websockets.ConnectionClosed:  # type: ignore
                 continue
 
-
     async def wait_for_one_websocket_message(self, send):
-        async with websockets.connect(self._ws_url) as websocket: #type: ignore
-            await websocket.send(json.dumps({"action": "want", "data": ["blocks", "mempool-blocks"]}))
+        async with websockets.connect(self._ws_url) as websocket:  # type: ignore
+            await websocket.send(
+                json.dumps({"action": "want", "data": ["blocks", "mempool-blocks"]})
+            )
             await websocket.send(json.dumps(send))
             raw = await asyncio.wait_for(websocket.recv(), timeout=10)
             return json.loads(raw) if raw else None
 
-
     async def wait_for_tx_confirmed(self, txid: str):
-        return await self.wait_for_websocket_message({"track-tx": txid }, "txConfirmed")
-
+        return await self.wait_for_websocket_message({"track-tx": txid}, "txConfirmed")
 
     async def wait_for_lockup_tx(self, address: str) -> LockupData:
-        message = await self.wait_for_websocket_message({"track-address": address }, "address-transactions")
+        message = await self.wait_for_websocket_message(
+            {"track-address": address}, "address-transactions"
+        )
         if not message:
             # restart
             return await self.wait_for_lockup_tx(address)
@@ -84,7 +85,6 @@ class MempoolClient:
             return await self.wait_for_lockup_tx(address)
         return lockup_tx
 
-
     def find_tx_and_output(self, txs, address: str) -> Optional[LockupData]:
         if len(txs) == 0:
             return None
@@ -92,10 +92,14 @@ class MempoolClient:
             for i, vout in enumerate(tx["vout"]):
                 if vout["scriptpubkey_address"] == address:
                     status = "confirmed" if tx["status"]["confirmed"] else "unconfirmed"
-                    return LockupData(txid=tx["txid"], vout_cnt=i, vout_amount=vout["value"], status=status)
+                    return LockupData(
+                        txid=tx["txid"],
+                        vout_cnt=i,
+                        vout_amount=vout["value"],
+                        status=status,
+                    )
         return None
 
-
     async def get_tx_from_address(self, address: str) -> LockupData:
         txs = self.request(
             "get",
@@ -109,7 +113,6 @@ class MempoolClient:
             return await self.wait_for_lockup_tx(address)
         return lockup_tx
 
-
     def get_fee_estimation(self) -> int:
         # TODO: hardcoded maximum tx size, in the future we try to get the size of the tx via embit
         # we need a function like Transaction.vsize()
@@ -117,7 +120,6 @@ class MempoolClient:
         mempool_fees = self.get_fees()
         return mempool_fees * tx_size_vbyte
 
-
     def get_fees(self) -> int:
         data = self.request(
             "get",
@@ -126,7 +128,6 @@ class MempoolClient:
         )
         return int(data["economyFee"])
 
-
     def get_blockheight(self) -> int:
         data = self.request(
             "get",
@@ -135,14 +136,12 @@ class MempoolClient:
         )
         return int(data["text"])
 
-
     def check_block_height(self, timeout_block_height: int) -> None:
         current_block_height = self.get_blockheight()
         if current_block_height < timeout_block_height:
             msg = f"current_block_height ({current_block_height}) has not yet exceeded ({timeout_block_height})"
             raise MempoolBlockHeightException(msg)
 
-
     def send_onchain_tx(self, tx_hex: str):
         return self.request(
             "post",
